Provides traits that must be implemented to be able to use generic algorithms.
Structs
- FstIter
Data - Paths
Iterator - Iterator on the paths recognized by an Fst.
- String
Paths Iterator - Iterator on the paths recognized by an Fst. Plus handles the SymbolTable to be able to retrieve the strings.
Traits
- Allocable
Fst - Trait defining the methods to control allocation for a wFST
- CoreFst
- Trait defining necessary methods for a wFST to access start states and final states.
- Expanded
Fst - Trait defining the necessary methods that should implement an ExpandedFST e.g a FST where all the states are already computed and not computed on the fly.
- Fst
- Trait defining the minimum interface necessary for a wFST.
- FstInto
Iterator - FstIterator
- Mutable
Fst - Trait defining the methods to modify a wFST.
- Serializable
Fst - Trait definining the methods an Fst must implement to be serialized and deserialized.
- State
Iterator - Trait to iterate over the states of a wFST.